==> qt-creator-opensource-src-4.6.0.zip: qt-creator-opensource-src-4.6.0/src/plugins/clangpchmanager/pchmanagerconnectionclient.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "pchmanagerconnectionclient.h"

#include <coreplugin/icore.h>

#include <utils/temporarydirectory.h>

#include <QCoreApplication>

namespace ClangPchManager {

namespace {

QString currentProcessId()
{
    return QString::number(QCoreApplication::applicationPid());
}

}

ClangPchManager::PchManagerConnectionClient::PchManagerConnectionClient(
        ClangBackEnd::PchManagerClientInterface *client)
    : ConnectionClient(Utils::TemporaryDirectory::masterDirectoryPath()
                       + QStringLiteral("/ClangPchManagerBackEnd-")
                       + currentProcessId()),
      m_serverProxy(client, ioDevice())
{
    m_processCreator.setTemporaryDirectoryPattern("clangpchmanagerbackend-XXXXXX");
    m_processCreator.setArguments({connectionName(),
                                   Core::ICore::userResourcePath() + "/symbol-experimental-v1.db"});

    stdErrPrefixer().setPrefix("PchManagerConnectionClient.stderr: ");
    stdOutPrefixer().setPrefix("PchManagerConnectionClient.stdout: ");
}

PchManagerConnectionClient::~PchManagerConnectionClient()
{
    finishProcess();
}

ClangBackEnd::PchManagerServerProxy &ClangPchManager::PchManagerConnectionClient::serverProxy()
{
    return m_serverProxy;
}

void ClangPchManager::PchManagerConnectionClient::sendEndCommand()
{
    m_serverProxy.end();
}

void PchManagerConnectionClient::resetCounter()
{
    m_serverProxy.resetCounter();
}

QString PchManagerConnectionClient::outputName() const
{
    return QStringLiteral("PchManagerConnectionClient");
}

void PchManagerConnectionClient::newConnectedServer(QIODevice *ioDevice)
{
    m_serverProxy.setIoDevice(ioDevice);
}

} // namespace ClangPchManager

==> qt-creator-opensource-src-4.7.2.zip: qt-creator-opensource-src-4.7.2/src/plugins/clangpchmanager/pchmanagerconnectionclient.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "pchmanagerconnectionclient.h"

#include <coreplugin/icore.h>

#include <utils/temporarydirectory.h>

#include <QCoreApplication>

namespace ClangPchManager {

namespace {

QString currentProcessId()
{
    return QString::number(QCoreApplication::applicationPid());
}

}

ClangPchManager::PchManagerConnectionClient::PchManagerConnectionClient(
        ClangBackEnd::PchManagerClientInterface *client)
    : ConnectionClient(Utils::TemporaryDirectory::masterDirectoryPath()
                       + QStringLiteral("/ClangPchManagerBackEnd-")
                       + currentProcessId()),
      m_serverProxy(client, ioDevice())
{
    m_processCreator.setTemporaryDirectoryPattern("clangpchmanagerbackend-XXXXXX");

    QDir pchsDirectory(Core::ICore::userResourcePath());
    pchsDirectory.mkdir("pchs");
    pchsDirectory.cd("pchs");
    m_processCreator.setArguments({connectionName(),
                                   Core::ICore::userResourcePath() + "/symbol-experimental-v1.db",
                                   pchsDirectory.absolutePath()});

    stdErrPrefixer().setPrefix("PchManagerConnectionClient.stderr: ");
    stdOutPrefixer().setPrefix("PchManagerConnectionClient.stdout: ");
}

PchManagerConnectionClient::~PchManagerConnectionClient()
{
    finishProcess();
}

ClangBackEnd::PchManagerServerProxy &ClangPchManager::PchManagerConnectionClient::serverProxy()
{
    return m_serverProxy;
}

void ClangPchManager::PchManagerConnectionClient::sendEndCommand()
{
    m_serverProxy.end();
}

void PchManagerConnectionClient::resetState()
{
    m_serverProxy.resetState();
}

QString PchManagerConnectionClient::outputName() const
{
    return QStringLiteral("PchManagerConnectionClient");
}

void PchManagerConnectionClient::newConnectedServer(QIODevice *ioDevice)
{
    m_serverProxy.setIoDevice(ioDevice);
}

} // namespace ClangPchManager
